@@ -5,9 +5,9 @@ from django.db.models.loading import get_app, get_models, get_model, load_app
 
 def get_all_models(app):
     try:
-        app_mod = load_app(app) # First try full path
+        app_mod = load_app(app)  # First try full path
     except ImportError:
-        app_mod = get_app(app) # Then try just app_label
+        app_mod = get_app(app)  # Then try just app_label
     return get_models(app_mod)
 
 
@@ -48,10 +48,12 @@ MODELS = parse_models(getattr(settings, 'SYNCHRO_MODELS', ()))
 INTER_MODELS = get_intermediary(MODELS)
 REMOTE = getattr(settings, 'SYNCHRO_REMOTE', None)
 LOCAL = 'default'
+ALLOW_RESET = getattr(settings, 'SYNCHRO_ALLOW_RESET', True)
+DEBUG = getattr(settings, 'SYNCHRO_DEBUG', False)
 
 if REMOTE is None:
     if not hasattr(settings, 'SYNCHRO_REMOTE'):
-        import  warnings
+        import warnings
         warnings.warn('SYNCHRO_REMOTE not specified. Synchronization is disabled.', RuntimeWarning)
 elif REMOTE not in settings.DATABASES:
     raise ImproperlyConfigured('SYNCHRO_REMOTE invalid - no such database: %s.' % REMOTE)
