@@ -26,7 +26,7 @@ if get_version() >= '1.5':
         "Check if installed User object is not too custom for the tests to instantiate it."
         from django.contrib.auth.models import User as StandardUser
         if (User.USERNAME_FIELD == StandardUser.USERNAME_FIELD and
-            User.REQUIRED_FIELDS == StandardUser.REQUIRED_FIELDS):
+                User.REQUIRED_FIELDS == StandardUser.REQUIRED_FIELDS):
             return True
         return False
 else:
@@ -39,7 +39,7 @@ REMOTE = settings.SYNCHRO_REMOTE
 SETTINGS = {
     'SYNCHRO_MODELS': (
         ('synchro', 'testmodel', 'PkModelWithSkip', 'ModelWithKey', 'ModelWithFK', 'A', 'X',
-         'M2mModelWithKey', 'M2mAnother', 'M2mModelWithInter', 'M2mSelf'),
+         'M2mModelWithKey', 'M2mAnother', 'M2mModelWithInter', 'M2mSelf', 'ModelWithFKtoKey'),
     )
 }
 
@@ -52,7 +52,7 @@ def contrib_apps(*apps):
     return True
 
 
-##### Test models ################################
+# #### Test models ################################
 
 
 class TestModel(models.Model):
@@ -119,6 +119,11 @@ class ModelWithKey(NaturalKeyModel):
     another_objects = MyNaturalManager()
 
 
+class ModelWithFKtoKey(models.Model):
+    name = models.CharField(max_length=10)
+    link = models.ForeignKey(ModelWithKey, related_name='links')
+
+
 class M2mModelWithKey(models.Model):
     foo = models.IntegerField(default=1)
     objects = NaturalManager('foo')
@@ -182,7 +187,7 @@ def update_bar_good_upd(sender, using, **kwargs):
     A.objects.db_manager(using).update(bar=F('bar') + 1)  # update don't emmit signals
 
 
-##### Tests themselves ###########################
+# #### Tests themselves ###########################
 
 
 @override_settings(**SETTINGS)
@@ -457,6 +462,16 @@ class SimpleSynchroTests(SynchroTests):
         self.assertEqual(a.name, b.name)
         self.assertEqual(a.cash, b.cash)
 
+    def test_reference2(self):
+        """Test if reference is created for model found with natural key."""
+        ModelWithKey.objects.db_manager(REMOTE).create(name='James')
+        loc = ModelWithKey.objects.create(name='James')
+        self.wait()
+        ModelWithFKtoKey.objects.create(name='Test', link=loc)
+        self.synchronize()
+        self.assertRemoteCount(1, ModelWithFKtoKey)
+        self.assertRemoteCount(1, ModelWithKey)
+
     def test_time_comparing(self):
         """Test if synchronization is not performed if REMOTE object is newer."""
         a = TestModel.objects.create(name="James", cash=7)
@@ -494,6 +509,21 @@ class SimpleSynchroTests(SynchroTests):
         self.assertRemoteCount(0, TestModel)
         self.client.post(path, {'synchro': True})  # button clicked
         self.assertRemoteCount(1, TestModel)
+        # resetting
+        self.assertGreater(ChangeLog.objects.count(), 0)
+        self.client.post(path, {'reset': True})  # button clicked
+        self.assertEqual(ChangeLog.objects.count(), 0)
+
+    def test_translation(self):
+        """Test if texts are translated."""
+        from django.utils.translation import override, force_unicode
+        from synchro import call_synchronize
+        languages = ('en', 'pl', 'de', 'es', 'fr')
+        messages = set()
+        for lang in languages:
+            with override(lang):
+                messages.add(force_unicode(call_synchronize()))
+        self.assertEqual(len(messages), len(languages), 'Some language is missing.')
 
 
 class AdvancedSynchroTests(SynchroTests):
@@ -804,7 +834,6 @@ class M2MSynchroTests(SynchroTests):
         inter = M2mIntermediate.objects.db_manager(REMOTE).all()[0]
         self.assertEqual(1, inter.cash)
 
-
         # Tricky: clear from other side of relation.
         self.wait()
         key2.r_m2m_i.clear()
